==> ejc-probid-api-3.0.0-20220825.081737-76-sources.jar: com/ejianc/business/record/vo/RecordVO.java <==
package com.ejianc.business.record.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 工程投标备案实体
 *
 * @author generator
 */
public class RecordVO extends BaseVO {
	private static final long serialVersionUID = 3584521432430641423L;

	private Long employeeId; // 经办人id
	private String employeeName; // 经办人名称
	private Date commitDate; // 提交日期
	private String commitUserName; // 提交人名称
	private String commitUserCode; // 提交人账号
	private Date effectiveDate; // 生效日期
	private String billCode; // 单据编码
	private String billName; // 单据名称
	private String billType; // 单据类型
	private Integer billState; // 单据状态
	private String billStateName; // 单据状态名称
	private Long projectId; // 项目id
	private String projectCode; // 项目编码
	private String projectName; // 项目名称
	private String constructionUnit; // 建设单位
	private String constructionUnitContact; // 建设单位联系人
	private String constructionUnitPhone; // 建设单位联系电话
	private String bidAgency; // 招标代理机构
	private String bidAgencyContact; // 招标代理机构联系人
	private String bidAgencyPhone; // 招标代理机构联系电话
	private Long bidUnitId; // 投标单位id
	private String bidUnitCode; // 投标单位编码
	private String bidUnitName; // 投标单位名称
	private String projectType; // 投标单位名称
	private BigDecimal projectTotalArea; // 项目总面积
	private Long structureId; // 结构id
	private String structureCode; // 结构编码
	private String structureName; // 结构名称
	private Integer layers; // 层数
	@JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
	private Date bidOpenDate; // 开标日期
	private String bidOpenPlace; // 开标地点
	private BigDecimal projectTotalMny; // 项目总投资
	private Long tenderModeId; // 招标方式id
	private String tenderModeCode; // 招标方式编码
	private String tenderModeName; // 招标方式名称
	private String evaluationMethod; // 评标办法 0-综合评估法、1-经评审的最低投标价法、2-其他
	private Long projectTypeId; // 项目类型id
	private String projectTypeCode; // 项目类型编码
	private String projectTypeName; // 项目类型名称
	private Long quoteModeId; // 报价方式id
	private String quoteModeCode; // 报价方式编码
	private String quoteModeName; // 报价方式名称
	private Long sourceBidTenderId; // 标书购买id
	private BigDecimal interceptTenderMny; // 拦标价
	private BigDecimal bidBond; // 投标保证金
	private BigDecimal performanceBond; // 履约保证金
	private String projectContentId; // 工程内容id
	private String projectContentCode; // 工程内容code
	private String projectContentName; // 工程内容name
	private String prepaymentAndPaymentMode; // 预付款及付款方式
	private String memo; // 备注

	private List<RecordFundVO> recordFundList = new ArrayList<>(); // 工程投标备案-资金情况实体
	private List<RecordRequirementVO> recordRequirementList = new ArrayList<>(); // 工程投标备案-投标要求实体
	private List<RecordStaffVO> recordStaffList = new ArrayList<>(); // 工程投标备案-人员要求实体
	private List<RecordEcoVO> recordEcoList = new ArrayList<>(); // 工程投标备案-主任经济师

	public Long getEmployeeId() {
		return employeeId;
	}

	@ReferDeserialTransfer
	public void setEmployeeId(Long employeeId) {
		this.employeeId = employeeId;
	}

	public String getEmployeeName() {
		return employeeName;
	}

	public void setEmployeeName(String employeeName) {
		this.employeeName = employeeName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public Date getEffectiveDate() {
		return effectiveDate;
	}

	public void setEffectiveDate(Date effectiveDate) {
		this.effectiveDate = effectiveDate;
	}

	public String getBillCode() {
		return billCode;
	}

	public void setBillCode(String billCode) {
		this.billCode = billCode;
	}

	public String getBillName() {
		return billName;
	}

	public void setBillName(String billName) {
		this.billName = billName;
	}

	public String getBillType() {
		return billType;
	}

	public void setBillType(String billType) {
		this.billType = billType;
	}

	public Integer getBillState() {
		return billState;
	}

	public void setBillState(Integer billState) {
		this.billState = billState;
	}

	public String getBillStateName() {
		return billStateName;
	}

	public void setBillStateName(String billStateName) {
		this.billStateName = billStateName;
	}

	public Long getProjectId() {
		return projectId;
	}

	@ReferDeserialTransfer
	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}

	public String getProjectCode() {
		return projectCode;
	}

	public void setProjectCode(String projectCode) {
		this.projectCode = projectCode;
	}

	public String getProjectName() {
		return projectName;
	}

	public void setProjectName(String projectName) {
		this.projectName = projectName;
	}

	public String getConstructionUnit() {
		return constructionUnit;
	}

	public void setConstructionUnit(String constructionUnit) {
		this.constructionUnit = constructionUnit;
	}

	public String getConstructionUnitContact() {
		return constructionUnitContact;
	}

	public void setConstructionUnitContact(String constructionUnitContact) {
		this.constructionUnitContact = constructionUnitContact;
	}

	public String getConstructionUnitPhone() {
		return constructionUnitPhone;
	}

	public void setConstructionUnitPhone(String constructionUnitPhone) {
		this.constructionUnitPhone = constructionUnitPhone;
	}

	public String getBidAgency() {
		return bidAgency;
	}

	public void setBidAgency(String bidAgency) {
		this.bidAgency = bidAgency;
	}

	public String getBidAgencyContact() {
		return bidAgencyContact;
	}

	public void setBidAgencyContact(String bidAgencyContact) {
		this.bidAgencyContact = bidAgencyContact;
	}

	public String getBidAgencyPhone() {
		return bidAgencyPhone;
	}

	public void setBidAgencyPhone(String bidAgencyPhone) {
		this.bidAgencyPhone = bidAgencyPhone;
	}

	public Long getBidUnitId() {
		return bidUnitId;
	}

	public void setBidUnitId(Long bidUnitId) {
		this.bidUnitId = bidUnitId;
	}

	public String getBidUnitCode() {
		return bidUnitCode;
	}

	public void setBidUnitCode(String bidUnitCode) {
		this.bidUnitCode = bidUnitCode;
	}

	public String getBidUnitName() {
		return bidUnitName;
	}

	public void setBidUnitName(String bidUnitName) {
		this.bidUnitName = bidUnitName;
	}

	public String getProjectType() {
		return projectType;
	}

	public void setProjectType(String projectType) {
		this.projectType = projectType;
	}

	public BigDecimal getProjectTotalArea() {
		return projectTotalArea;
	}

	public void setProjectTotalArea(BigDecimal projectTotalArea) {
		this.projectTotalArea = projectTotalArea;
	}

	public Long getStructureId() {
		return structureId;
	}

	@ReferDeserialTransfer
	public void setStructureId(Long structureId) {
		this.structureId = structureId;
	}

	public String getStructureCode() {
		return structureCode;
	}

	public void setStructureCode(String structureCode) {
		this.structureCode = structureCode;
	}

	public String getStructureName() {
		return structureName;
	}

	public void setStructureName(String structureName) {
		this.structureName = structureName;
	}

	public Integer getLayers() {
		return layers;
	}

	public void setLayers(Integer layers) {
		this.layers = layers;
	}

	public Date getBidOpenDate() {
		return bidOpenDate;
	}

	public void setBidOpenDate(Date bidOpenDate) {
		this.bidOpenDate = bidOpenDate;
	}

	public String getBidOpenPlace() {
		return bidOpenPlace;
	}

	public void setBidOpenPlace(String bidOpenPlace) {
		this.bidOpenPlace = bidOpenPlace;
	}

	public BigDecimal getProjectTotalMny() {
		return projectTotalMny;
	}

	public void setProjectTotalMny(BigDecimal projectTotalMny) {
		this.projectTotalMny = projectTotalMny;
	}

	public Long getTenderModeId() {
		return tenderModeId;
	}

	@ReferDeserialTransfer
	public void setTenderModeId(Long tenderModeId) {
		this.tenderModeId = tenderModeId;
	}

	public String getTenderModeCode() {
		return tenderModeCode;
	}

	public void setTenderModeCode(String tenderModeCode) {
		this.tenderModeCode = tenderModeCode;
	}

	public String getTenderModeName() {
		return tenderModeName;
	}

	public void setTenderModeName(String tenderModeName) {
		this.tenderModeName = tenderModeName;
	}

	public String getEvaluationMethod() {
		return evaluationMethod;
	}

	public void setEvaluationMethod(String evaluationMethod) {
		this.evaluationMethod = evaluationMethod;
	}

	public Long getProjectTypeId() {
		return projectTypeId;
	}

	@ReferDeserialTransfer
	public void setProjectTypeId(Long projectTypeId) {
		this.projectTypeId = projectTypeId;
	}

	public String getProjectTypeCode() {
		return projectTypeCode;
	}

	public void setProjectTypeCode(String projectTypeCode) {
		this.projectTypeCode = projectTypeCode;
	}

	public String getProjectTypeName() {
		return projectTypeName;
	}

	public void setProjectTypeName(String projectTypeName) {
		this.projectTypeName = projectTypeName;
	}

	public Long getQuoteModeId() {
		return quoteModeId;
	}

	@ReferDeserialTransfer
	public void setQuoteModeId(Long quoteModeId) {
		this.quoteModeId = quoteModeId;
	}

	public String getQuoteModeCode() {
		return quoteModeCode;
	}

	public void setQuoteModeCode(String quoteModeCode) {
		this.quoteModeCode = quoteModeCode;
	}

	public String getQuoteModeName() {
		return quoteModeName;
	}

	public void setQuoteModeName(String quoteModeName) {
		this.quoteModeName = quoteModeName;
	}

	public Long getSourceBidTenderId() {
		return sourceBidTenderId;
	}

	public void setSourceBidTenderId(Long sourceBidTenderId) {
		this.sourceBidTenderId = sourceBidTenderId;
	}

	public BigDecimal getInterceptTenderMny() {
		return interceptTenderMny;
	}

	public void setInterceptTenderMny(BigDecimal interceptTenderMny) {
		this.interceptTenderMny = interceptTenderMny;
	}

	public BigDecimal getBidBond() {
		return bidBond;
	}

	public void setBidBond(BigDecimal bidBond) {
		this.bidBond = bidBond;
	}

	public BigDecimal getPerformanceBond() {
		return performanceBond;
	}

	public void setPerformanceBond(BigDecimal performanceBond) {
		this.performanceBond = performanceBond;
	}

	public String getProjectContentId() {
		return projectContentId;
	}

	@ReferDeserialTransfer
	public void setProjectContentId(String projectContentId) {
		this.projectContentId = projectContentId;
	}

	public String getProjectContentCode() {
		return projectContentCode;
	}

	public void setProjectContentCode(String projectContentCode) {
		this.projectContentCode = projectContentCode;
	}

	public String getProjectContentName() {
		return projectContentName;
	}

	public void setProjectContentName(String projectContentName) {
		this.projectContentName = projectContentName;
	}

	public String getPrepaymentAndPaymentMode() {
		return prepaymentAndPaymentMode;
	}

	public void setPrepaymentAndPaymentMode(String prepaymentAndPaymentMode) {
		this.prepaymentAndPaymentMode = prepaymentAndPaymentMode;
	}

	public String getMemo() {
		return memo;
	}

	public void setMemo(String memo) {
		this.memo = memo;
	}

	public List<RecordFundVO> getRecordFundList() {
		return recordFundList;
	}

	public void setRecordFundList(List<RecordFundVO> recordFundList) {
		this.recordFundList = recordFundList;
	}

	public List<RecordRequirementVO> getRecordRequirementList() {
		return recordRequirementList;
	}

	public void setRecordRequirementList(List<RecordRequirementVO> recordRequirementList) {
		this.recordRequirementList = recordRequirementList;
	}

	public List<RecordStaffVO> getRecordStaffList() {
		return recordStaffList;
	}

	public void setRecordStaffList(List<RecordStaffVO> recordStaffList) {
		this.recordStaffList = recordStaffList;
	}

	public List<RecordEcoVO> getRecordEcoList() {
		return recordEcoList;
	}

	public void setRecordEcoList(List<RecordEcoVO> recordEcoList) {
		this.recordEcoList = recordEcoList;
	}
}

==> ejc-probid-api-3.0.0-20220825.092506-77-sources.jar: com/ejianc/business/record/vo/RecordVO.java <==
package com.ejianc.business.record.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 工程投标备案实体
 *
 * @author generator
 */
public class RecordVO extends BaseVO {
	private static final long serialVersionUID = 3584521432430641423L;

	private Long employeeId; // 经办人id
	private String employeeName; // 经办人名称
	private Date commitDate; // 提交日期
	private String commitUserName; // 提交人名称
	private String commitUserCode; // 提交人账号
	private Date effectiveDate; // 生效日期
	private String billCode; // 单据编码
	private String billName; // 单据名称
	private String billType; // 单据类型
	private Integer billState; // 单据状态
	private String billStateName; // 单据状态名称
	private Long projectId; // 项目id
	private String projectCode; // 项目编码
	private String projectName; // 项目名称
	private String constructionUnit; // 建设单位
	private String constructionUnitContact; // 建设单位联系人
	private String constructionUnitPhone; // 建设单位联系电话
	private String bidAgency; // 招标代理机构
	private String bidAgencyContact; // 招标代理机构联系人
	private String bidAgencyPhone; // 招标代理机构联系电话
	private Long bidUnitId; // 投标单位id
	private String bidUnitCode; // 投标单位编码
	private String bidUnitName; // 投标单位名称
	private String projectType; // 投标单位名称
	private BigDecimal projectTotalArea; // 项目总面积
	private Long structureId; // 结构id
	private String structureCode; // 结构编码
	private String structureName; // 结构名称
	private Integer layers; // 层数
	@JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
	private Date bidOpenDate; // 开标日期
	private String bidOpenPlace; // 开标地点
	private BigDecimal projectTotalMny; // 项目总投资
	private Long tenderModeId; // 招标方式id
	private String tenderModeCode; // 招标方式编码
	private String tenderModeName; // 招标方式名称
	private String evaluationMethod; // 评标办法 0-综合评估法、1-经评审的最低投标价法、2-其他
	private Long projectTypeId; // 项目类型id
	private String projectTypeCode; // 项目类型编码
	private String projectTypeName; // 项目类型名称
	private Long quoteModeId; // 报价方式id
	private String quoteModeCode; // 报价方式编码
	private String quoteModeName; // 报价方式名称
	private Long sourceBidTenderId; // 标书购买id
	private BigDecimal interceptTenderMny; // 拦标价
	private BigDecimal bidBond; // 投标保证金
	private BigDecimal performanceBond; // 履约保证金
	private String projectContentId; // 工程内容id
	private String projectContentCode; // 工程内容code
	private String projectContentName; // 工程内容name
	private String prepaymentAndPaymentMode; // 预付款及付款方式
	private String memo; // 备注

	private List<RecordFundVO> recordFundList = new ArrayList<>(); // 工程投标备案-资金情况实体
	private List<RecordRequirementVO> recordRequirementList = new ArrayList<>(); // 工程投标备案-投标要求实体
	private List<RecordStaffVO> recordStaffList = new ArrayList<>(); // 工程投标备案-人员要求实体
	private RecordEcoVO recordEco; // 工程投标备案-主任经济师

	public Long getEmployeeId() {
		return employeeId;
	}

	@ReferDeserialTransfer
	public void setEmployeeId(Long employeeId) {
		this.employeeId = employeeId;
	}

	public String getEmployeeName() {
		return employeeName;
	}

	public void setEmployeeName(String employeeName) {
		this.employeeName = employeeName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public Date getEffectiveDate() {
		return effectiveDate;
	}

	public void setEffectiveDate(Date effectiveDate) {
		this.effectiveDate = effectiveDate;
	}

	public String getBillCode() {
		return billCode;
	}

	public void setBillCode(String billCode) {
		this.billCode = billCode;
	}

	public String getBillName() {
		return billName;
	}

	public void setBillName(String billName) {
		this.billName = billName;
	}

	public String getBillType() {
		return billType;
	}

	public void setBillType(String billType) {
		this.billType = billType;
	}

	public Integer getBillState() {
		return billState;
	}

	public void setBillState(Integer billState) {
		this.billState = billState;
	}

	public String getBillStateName() {
		return billStateName;
	}

	public void setBillStateName(String billStateName) {
		this.billStateName = billStateName;
	}

	public Long getProjectId() {
		return projectId;
	}

	@ReferDeserialTransfer
	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}

	public String getProjectCode() {
		return projectCode;
	}

	public void setProjectCode(String projectCode) {
		this.projectCode = projectCode;
	}

	public String getProjectName() {
		return projectName;
	}

	public void setProjectName(String projectName) {
		this.projectName = projectName;
	}

	public String getConstructionUnit() {
		return constructionUnit;
	}

	public void setConstructionUnit(String constructionUnit) {
		this.constructionUnit = constructionUnit;
	}

	public String getConstructionUnitContact() {
		return constructionUnitContact;
	}

	public void setConstructionUnitContact(String constructionUnitContact) {
		this.constructionUnitContact = constructionUnitContact;
	}

	public String getConstructionUnitPhone() {
		return constructionUnitPhone;
	}

	public void setConstructionUnitPhone(String constructionUnitPhone) {
		this.constructionUnitPhone = constructionUnitPhone;
	}

	public String getBidAgency() {
		return bidAgency;
	}

	public void setBidAgency(String bidAgency) {
		this.bidAgency = bidAgency;
	}

	public String getBidAgencyContact() {
		return bidAgencyContact;
	}

	public void setBidAgencyContact(String bidAgencyContact) {
		this.bidAgencyContact = bidAgencyContact;
	}

	public String getBidAgencyPhone() {
		return bidAgencyPhone;
	}

	public void setBidAgencyPhone(String bidAgencyPhone) {
		this.bidAgencyPhone = bidAgencyPhone;
	}

	public Long getBidUnitId() {
		return bidUnitId;
	}

	public void setBidUnitId(Long bidUnitId) {
		this.bidUnitId = bidUnitId;
	}

	public String getBidUnitCode() {
		return bidUnitCode;
	}

	public void setBidUnitCode(String bidUnitCode) {
		this.bidUnitCode = bidUnitCode;
	}

	public String getBidUnitName() {
		return bidUnitName;
	}

	public void setBidUnitName(String bidUnitName) {
		this.bidUnitName = bidUnitName;
	}

	public String getProjectType() {
		return projectType;
	}

	public void setProjectType(String projectType) {
		this.projectType = projectType;
	}

	public BigDecimal getProjectTotalArea() {
		return projectTotalArea;
	}

	public void setProjectTotalArea(BigDecimal projectTotalArea) {
		this.projectTotalArea = projectTotalArea;
	}

	public Long getStructureId() {
		return structureId;
	}

	@ReferDeserialTransfer
	public void setStructureId(Long structureId) {
		this.structureId = structureId;
	}

	public String getStructureCode() {
		return structureCode;
	}

	public void setStructureCode(String structureCode) {
		this.structureCode = structureCode;
	}

	public String getStructureName() {
		return structureName;
	}

	public void setStructureName(String structureName) {
		this.structureName = structureName;
	}

	public Integer getLayers() {
		return layers;
	}

	public void setLayers(Integer layers) {
		this.layers = layers;
	}

	public Date getBidOpenDate() {
		return bidOpenDate;
	}

	public void setBidOpenDate(Date bidOpenDate) {
		this.bidOpenDate = bidOpenDate;
	}

	public String getBidOpenPlace() {
		return bidOpenPlace;
	}

	public void setBidOpenPlace(String bidOpenPlace) {
		this.bidOpenPlace = bidOpenPlace;
	}

	public BigDecimal getProjectTotalMny() {
		return projectTotalMny;
	}

	public void setProjectTotalMny(BigDecimal projectTotalMny) {
		this.projectTotalMny = projectTotalMny;
	}

	public Long getTenderModeId() {
		return tenderModeId;
	}

	@ReferDeserialTransfer
	public void setTenderModeId(Long tenderModeId) {
		this.tenderModeId = tenderModeId;
	}

	public String getTenderModeCode() {
		return tenderModeCode;
	}

	public void setTenderModeCode(String tenderModeCode) {
		this.tenderModeCode = tenderModeCode;
	}

	public String getTenderModeName() {
		return tenderModeName;
	}

	public void setTenderModeName(String tenderModeName) {
		this.tenderModeName = tenderModeName;
	}

	public String getEvaluationMethod() {
		return evaluationMethod;
	}

	public void setEvaluationMethod(String evaluationMethod) {
		this.evaluationMethod = evaluationMethod;
	}

	public Long getProjectTypeId() {
		return projectTypeId;
	}

	@ReferDeserialTransfer
	public void setProjectTypeId(Long projectTypeId) {
		this.projectTypeId = projectTypeId;
	}

	public String getProjectTypeCode() {
		return projectTypeCode;
	}

	public void setProjectTypeCode(String projectTypeCode) {
		this.projectTypeCode = projectTypeCode;
	}

	public String getProjectTypeName() {
		return projectTypeName;
	}

	public void setProjectTypeName(String projectTypeName) {
		this.projectTypeName = projectTypeName;
	}

	public Long getQuoteModeId() {
		return quoteModeId;
	}

	@ReferDeserialTransfer
	public void setQuoteModeId(Long quoteModeId) {
		this.quoteModeId = quoteModeId;
	}

	public String getQuoteModeCode() {
		return quoteModeCode;
	}

	public void setQuoteModeCode(String quoteModeCode) {
		this.quoteModeCode = quoteModeCode;
	}

	public String getQuoteModeName() {
		return quoteModeName;
	}

	public void setQuoteModeName(String quoteModeName) {
		this.quoteModeName = quoteModeName;
	}

	public Long getSourceBidTenderId() {
		return sourceBidTenderId;
	}

	public void setSourceBidTenderId(Long sourceBidTenderId) {
		this.sourceBidTenderId = sourceBidTenderId;
	}

	public BigDecimal getInterceptTenderMny() {
		return interceptTenderMny;
	}

	public void setInterceptTenderMny(BigDecimal interceptTenderMny) {
		this.interceptTenderMny = interceptTenderMny;
	}

	public BigDecimal getBidBond() {
		return bidBond;
	}

	public void setBidBond(BigDecimal bidBond) {
		this.bidBond = bidBond;
	}

	public BigDecimal getPerformanceBond() {
		return performanceBond;
	}

	public void setPerformanceBond(BigDecimal performanceBond) {
		this.performanceBond = performanceBond;
	}

	public String getProjectContentId() {
		return projectContentId;
	}

	@ReferDeserialTransfer
	public void setProjectContentId(String projectContentId) {
		this.projectContentId = projectContentId;
	}

	public String getProjectContentCode() {
		return projectContentCode;
	}

	public void setProjectContentCode(String projectContentCode) {
		this.projectContentCode = projectContentCode;
	}

	public String getProjectContentName() {
		return projectContentName;
	}

	public void setProjectContentName(String projectContentName) {
		this.projectContentName = projectContentName;
	}

	public String getPrepaymentAndPaymentMode() {
		return prepaymentAndPaymentMode;
	}

	public void setPrepaymentAndPaymentMode(String prepaymentAndPaymentMode) {
		this.prepaymentAndPaymentMode = prepaymentAndPaymentMode;
	}

	public String getMemo() {
		return memo;
	}

	public void setMemo(String memo) {
		this.memo = memo;
	}

	public List<RecordFundVO> getRecordFundList() {
		return recordFundList;
	}

	public void setRecordFundList(List<RecordFundVO> recordFundList) {
		this.recordFundList = recordFundList;
	}

	public List<RecordRequirementVO> getRecordRequirementList() {
		return recordRequirementList;
	}

	public void setRecordRequirementList(List<RecordRequirementVO> recordRequirementList) {
		this.recordRequirementList = recordRequirementList;
	}

	public List<RecordStaffVO> getRecordStaffList() {
		return recordStaffList;
	}

	public void setRecordStaffList(List<RecordStaffVO> recordStaffList) {
		this.recordStaffList = recordStaffList;
	}

	public RecordEcoVO getRecordEco() {
		return recordEco;
	}

	public void setRecordEco(RecordEcoVO recordEco) {
		this.recordEco = recordEco;
	}
}
